@@ -55,6 +55,7 @@
 class GpuContextSpecificNext;
 struct _MOS_VIRTUALENGINE_SET_PARAMS;
 struct _MOS_VIRTUALENGINE_INIT_PARAMS;
+struct SYNC_FENCE_INFO_TRINITY;
 
 typedef struct _MOS_VIRTUALENGINE_SET_PARAMS  MOS_VIRTUALENGINE_SET_PARAMS, *PMOS_VIRTUALENGINE_SET_PARAMS;
 typedef struct _MOS_VIRTUALENGINE_INIT_PARAMS MOS_VIRTUALENGINE_INIT_PARAMS, *PMOS_VIRTUALENGINE_INIT_PARAMS;
@@ -482,6 +483,13 @@ public:
     //!
     //! \brief    Dump Indirect state in Command Buffer
     //!
+    static MOS_STATUS DumpIndirectStates(
+        MOS_STREAM_HANDLE streamState,
+        const char        *filePathPrefix,
+        std::time_t       currentTime);
+    //!
+    //! \brief    Dump Indirect state in Command Buffer
+    //!
     //! \param    [in] streamState
     //!           Handle of Os Stream State
     //! \param    [in] cmdBuffer
@@ -494,7 +502,7 @@ public:
     //! \return   MOS_STATUS
     //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
     //!
-    static MOS_STATUS DumpIndirectState(
+    static MOS_STATUS DumpBindingTable(
         MOS_STREAM_HANDLE     streamState,
         COMMAND_BUFFER_HANDLE cmdBuffer,
         MOS_GPU_NODE          gpuNode,
@@ -1411,18 +1419,21 @@ public:
     //!           GPU Context handle of current GPU which requesting to use the resoure and find the hazard to wait the busy context.
     //! \param    [in] osRequestorHandle
     //!           OS runtime handle of requestor context
+    //! \param    [in,out] fenceInfoTrinity
+    //!           if need to sync, it is fence handle and fence value
     //!
     //! \return   MOS_STATUS
     //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
     //!
-    static MOS_STATUS ResourceSyncCallback(    
+    static MOS_STATUS ResourceSyncCallback(
         OsSpecificRes          resource,
         MOS_DEVICE_HANDLE      deviceContext,
         uint32_t               index,
         SYNC_HAZARD            hazardType,
         GPU_CONTEXT_HANDLE     busyCtx,
         GPU_CONTEXT_HANDLE     requestorCtx,
-        OS_HANDLE              osRequestorHandle);
+        OS_HANDLE              osRequestorHandle,
+        SYNC_FENCE_INFO_TRINITY *fenceInfoTrinity);
 
     //!
     //! \brief    Lock Sync Callback between Media and 3D
@@ -1657,6 +1668,26 @@ public:
         MOS_RESOURCE_HANDLE outputResource,
         bool                outputCompressed);
 
+    //!
+    //! \brief    Use media copy to copy resource
+    //!
+    //! \param    [in] streamState
+    //!           Handle of Os Stream State
+    //! \param    [in] inputResource
+    //!           Source resource.
+    //! \param    [out] outputResource
+    //!           Destination resource.
+    //! \param    [in] preferMethod
+    //!           Preferred copy engine.
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    static MOS_STATUS UnifiedMediaCopyResource(
+        MOS_STREAM_HANDLE   streamState,
+        MOS_RESOURCE_HANDLE inputResource,
+        MOS_RESOURCE_HANDLE outputResource,
+        int                 preferMethod);
+
     //!
     //! \brief    Copy Resource to Another Buffer
     //! \details  Decompress and Copy Resource to Another 2D Buffer
@@ -1667,6 +1698,38 @@ public:
     //!           [in] Input Resource object
     //! \param    outputResource
     //!           [out] output Resource object
+    //! \param    [in] copyPitch
+    //!           The 2D surface pitch
+    //! \param    [in] copyHeight
+    //!           The 2D surface height
+    //! \param    [in] copyInputOffset
+    //!           The offset of copied surface from
+    //! \param    [in] copyOutputOffset
+    //!           The offset of copied to
+    //! \param    [in] outputCompressed
+    //!           True means apply compression on output surface, else output uncompressed surface
+    //! \return   MOS_STATUS
+    //!           MOS_STATUS_SUCCESS if successful
+    //!
+    static MOS_STATUS MediaCopyResource2D(
+        MOS_STREAM_HANDLE   streamState,
+        MOS_RESOURCE_HANDLE inputResource,
+        MOS_RESOURCE_HANDLE outputResource,
+        uint32_t            copyPitch,
+        uint32_t            copyHeight,
+        uint32_t            bpp,
+        bool                outputCompressed);
+
+    //!
+    //! \brief    Copy Mono Resource to Another Buffer
+    //! \details  Decompress and Copy Mono Resource to Another 2D Buffer
+    //!
+    //! \param    [in] streamState
+    //!           Handle of Os Stream State
+    //! \param    inputResource
+    //!           [in] Input Resource object
+    //! \param    outputResource
+    //!           [out] output Resource object
     //! \param    [in] copyWidth
     //!           The 2D surface Width
     //! \param    [in] copyHeight
@@ -1680,15 +1743,14 @@ public:
     //! \return   MOS_STATUS
     //!           MOS_STATUS_SUCCESS if successful
     //!
-    static MOS_STATUS MediaCopyResource2D(
+    static MOS_STATUS MonoSurfaceCopy(
         MOS_STREAM_HANDLE   streamState,
         MOS_RESOURCE_HANDLE inputResource,
         MOS_RESOURCE_HANDLE outputResource,
-        uint32_t            copyWidth,
+        uint32_t            copyPitch,
         uint32_t            copyHeight,
         uint32_t            copyInputOffset,
         uint32_t            copyOutputOffset,
-        uint32_t            bpp,
         bool                outputCompressed);
 
     //!
@@ -1811,40 +1873,6 @@ public:
     //!
     static MOS_STATUS MosFreeLibrary(HMODULE hLibModule);
 
-    //! \brief    Get Virtual Engine State
-    //! \details  [Virtual Engine Interface] Get Virtual Engine State from streamState
-    //! \details  Caller: Hal (Scalability) only
-    //! \details  This func is called when a stream (Hal instance) need to get a VE state
-    //! \details  corresponding to current GPU context.
-    //!
-    //! \param    [in] streamState
-    //!           Handle of Os Stream State
-    //!
-    //! \return   MOS_VE_HANDLE
-    //!           Handle of MOS virtual engine state, Invalid handle if get failed 
-    //!
-    static MOS_VE_HANDLE GetVirtualEngineState(
-        MOS_STREAM_HANDLE  streamState);
-
-    //!
-    //! \brief    Set Virtual Engine State
-    //! \details  [Virtual Engine Interface] Set Virtual Engine State of provided streamState
-    //! \details  Caller: Hal (Scalability) only
-    //! \details  This func is called when a stream (Hal instance) need to set an existing VE state
-    //! \details  into provided stream.
-    //!
-    //! \param    [in] streamState
-    //!           Handle of Os Stream State
-    //! \param    [in] veState
-    //!           Handle of Virtual Engine State to set
-    //!
-    //! \return   MOS_STATUS
-    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
-    //!
-    static MOS_STATUS SetVirtualEngineState(
-        MOS_STREAM_HANDLE streamState,
-        MOS_VE_HANDLE veState);
-
     //!
     //! \brief    Create Virtual Engine State
     //! \details  [Virtual Engine Interface] Create Virtual Engine State of provided streamState
@@ -2311,6 +2339,9 @@ public:
 
     static uint64_t GetResourceHandle(MOS_STREAM_HANDLE streamState, PMOS_RESOURCE osResource);
 
+    static void SetIsTrinityEnabled(bool bTrinity);
+
+    static bool IsGpuSyncByCmd(MOS_STREAM_HANDLE streamState);
 private:
     //!
     //! \brief    Init per stream parameters
@@ -2410,6 +2441,7 @@ private:
     static uint32_t m_mosOsApiFailSimulateHint;
     static uint32_t m_mosOsApiFailSimulateCounter;
 #endif
+    static bool m_bTrinity;
 MEDIA_CLASS_DEFINE_END(MosInterface)
 };
 
