@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2022, Intel Corporation
+* Copyright (c) 2018-2024, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -89,6 +89,16 @@ typedef enum _VPHAL_COMP_BYPASS_MODE
     VPHAL_COMP_BYPASS_DEFAULT  = 0x2
 } VPHAL_COMP_BYPASS_MODE, *PVPHAL_COMP_BYPASS_MODE;
 
+//!
+//! \brief VP CTRL enum
+//!
+typedef enum _VP_CTRL
+{
+    VP_CTRL_DISABLE = 0,
+    VP_CTRL_ENABLE,
+    VP_CTRL_DEFAULT
+} VP_CTRL;
+
 struct VP_SURFACE
 {
     MOS_SURFACE                 *osSurface      = nullptr;         //!< mos surface
@@ -165,6 +175,7 @@ struct _VP_EXECUTE_CAPS
             uint64_t bBt2020ToRGB   : 1;   // Vebox Bt2020 gamut compression to RGB format
             uint64_t bProcamp       : 1;   // Vebox Procamp needed
             uint64_t bBeCSC         : 1;   // Vebox back end CSC needed
+            uint64_t bFeCSC         : 1;   // Vebox front end CSC needed
             uint64_t bLACE          : 1;   // Vebox LACE Needed
             uint64_t bQueryVariance : 1;
             uint64_t bRefValid      : 1;   // Vebox Ref is Valid
@@ -182,6 +193,8 @@ struct _VP_EXECUTE_CAPS
             uint64_t bColorBalance  : 1;
             uint64_t b1K1DLutInUse  : 1;
             uint64_t bCcmCsc        : 1;
+            uint64_t bDemosaicInUse : 1;
+            uint64_t enableSFCLinearOutputByTileConvert : 1;  //true if do tileconvert from tileF to linear for SFC linear output
 
             // SFC features
             uint64_t bSfcCsc        : 1;   // Sfc Csc enabled
@@ -197,6 +210,8 @@ struct _VP_EXECUTE_CAPS
             uint64_t bHVSCalc       : 1;
             uint64_t bSegmentation  : 1;
             uint64_t bHdr           : 1;
+            uint64_t bFallbackLegacyFC : 1;     // only valid when vpUserFeatureControl->EnableOclFC() is true
+            uint64_t forceBypassWorkload : 1;  // If true, force to bypass workload.
         };
         uint64_t value;
     };
@@ -222,6 +237,9 @@ typedef struct _VP_EngineEntry
             uint64_t bt2020ToRGB : 1;           // true if bt2020 to rgb
             uint64_t is1K1DLutSurfaceInUse : 1;  // 1K1DLut surface in use
             uint64_t isHdr33LutSizeEnabled : 1;
+            uint64_t isBayerInputInUse : 1;
+            uint64_t frontEndCscNeeded : 1;  // true if use vebox front end csc to do output csc feature instead of using backendcsc + sfc. Only using it when no scaling needed
+            uint64_t forceLegacyFC : 1;          // true if OCL FC not support the format, fall back to legacy FC
 
             // set by GetXxxPipeEnginCaps
             uint64_t bypassIfVeboxSfcInUse : 1;  // Bypass the feature if vebox or sfc in use. In such case, VeboxNeeded and
@@ -247,6 +265,8 @@ typedef struct _VP_EngineEntry
             uint64_t sfcOnlyFeatureExists : 1;  // The feature exists, which only support sfc.
             uint64_t bTemperalInputInuse : 1;   // true if replace input
             uint64_t outputWithLumaKey : 1;
+            uint64_t enableSFCLinearOutputByTileConvert : 1;  //true if do tileconvert from tileF to linear for SFC linear output
+            uint64_t forceBypassWorkload : 1;   // If true, force to bypass workload.
         };
         uint64_t value;
     };
@@ -289,7 +309,6 @@ union RESOURCE_ASSIGNMENT_HINT
     uint32_t value[RESOURCE_ASSIGNMENT_HINT_SIZE];
 };
 
-using PVP_MHWINTERFACE = VP_MHWINTERFACE * ;
 using VP_EXECUTE_CAPS  = _VP_EXECUTE_CAPS;
 using VP_PACKET_ENGINE = _VP_PACKET_ENGINE;
 using PVP_SURFACE      = VP_SURFACE*;
